@@ -5,7 +5,7 @@
  * Copyright (C) 2001 Jonathan Blandford
  *
  * Written by: Bradford Hovinen <hovinen@ximian.com>
- *             Richard Hestilow <hestilow@ximian.com>
+ *             Rachel Hestilow <hestilow@ximian.com>
  *	       Jonathan Blandford <jrb@redhat.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -34,6 +34,8 @@
 
 #include "capplet-util.h"
 #include "gconf-property-editor.h"
+#include "activate-settings-daemon.h"
+#include <../accessibility/keyboard/accessibility-keyboard.h>
 
 enum
 {
@@ -52,7 +54,7 @@ create_dialog (void)
 }
 
 static GConfValue *
-rate_to_widget (GConfValue *value) 
+rate_to_widget (GConfPropertyEditor *peditor, const GConfValue *value)
 {
 	GConfValue *new_value;
 	int rate;
@@ -74,7 +76,7 @@ rate_to_widget (GConfValue *value)
 }
 
 static GConfValue *
-rate_from_widget (GConfValue *value) 
+rate_from_widget (GConfPropertyEditor *peditor, const GConfValue *value)
 {
 	static int rates[] = {
 		255, 192, 64, 1
@@ -89,7 +91,7 @@ rate_from_widget (GConfValue *value)
 }
 
 static GConfValue *
-delay_to_widget (GConfValue *value) 
+delay_to_widget (GConfPropertyEditor *peditor, const GConfValue *value)
 {
 	GConfValue *new_value;
 	int delay;
@@ -111,7 +113,7 @@ delay_to_widget (GConfValue *value)
 }
 
 static GConfValue *
-delay_from_widget (GConfValue *value) 
+delay_from_widget (GConfPropertyEditor *peditor, GConfValue *value) 
 {
 	static int delays[] = {
 		1000, 700, 300, 0
@@ -125,13 +127,13 @@ delay_from_widget (GConfValue *value)
 }
 
 static GConfEnumStringPair bell_enums[] = {
-	{ 0, "custom" },
+	{ 0, "off" },
 	{ 1, "on" },
-	{ 2, "off" }
+	{ 2, "custom" }
 };
 
 static GConfValue *
-bell_from_widget (GConfValue *value) 
+bell_from_widget (GConfPropertyEditor *peditor, const GConfValue *value)
 {
 	GConfValue *new_value;
 
@@ -143,15 +145,20 @@ bell_from_widget (GConfValue *value)
 }
 
 static GConfValue *
-bell_to_widget (GConfValue *value) 
+bell_to_widget (GConfPropertyEditor *peditor, const GConfValue *value)
 {
 	GConfValue *new_value;
+	const gchar *str;
 	gint val = 2;
 
+	str = (value && (value->type == GCONF_VALUE_STRING)) ? gconf_value_get_string (value) : NULL;
+
 	new_value = gconf_value_new (GCONF_VALUE_INT);
-	gconf_string_to_enum (bell_enums,
-			      gconf_value_get_string (value),
-			      &val);
+	if (value->type == GCONF_VALUE_STRING) {
+		gconf_string_to_enum (bell_enums,
+				      str,
+				      &val);
+	}
 	gconf_value_set_int (new_value, val);
 
 	return new_value;
@@ -159,7 +166,7 @@ bell_to_widget (GConfValue *value)
 
 
 static GConfValue *
-blink_from_widget (GConfValue *value) 
+blink_from_widget (GConfPropertyEditor *peditor, const GConfValue *value)
 {
 	GConfValue *new_value;
 
@@ -170,7 +177,7 @@ blink_from_widget (GConfValue *value)
 }
 
 static GConfValue *
-blink_to_widget (GConfValue *value) 
+blink_to_widget (GConfPropertyEditor *peditor, const GConfValue *value)
 {
 	GConfValue *new_value;
 	gint current_rate;
@@ -182,6 +189,17 @@ blink_to_widget (GConfValue *value)
 	return new_value;
 }
 
+static GConfValue *
+volume_to_widget (GConfPropertyEditor *peditor, const GConfValue *value)
+{
+	return gconf_value_int_to_float (value);
+}
+static GConfValue *
+volume_from_widget (GConfPropertyEditor *peditor, const GConfValue *value)
+{
+	return gconf_value_float_to_int (value);
+}
+
 static void
 bell_guard (GtkWidget *toggle,
 	    GladeXML  *dialog)
@@ -215,6 +233,13 @@ dialog_response (GtkWidget *widget,
 	}
 }
 
+static void
+accessibility_button_clicked (GtkWidget *widget,
+			      gpointer   data)
+{
+	g_spawn_command_line_async ("gnome-accessibility-keyboard-properties", NULL);
+}
+
 static void
 setup_dialog (GladeXML       *dialog,
 	      GConfChangeSet *changeset)
@@ -268,7 +293,10 @@ setup_dialog (GladeXML       *dialog,
 		(changeset, "/desktop/gnome/peripherals/keyboard/click", WID ("volume_toggle"), NULL);
 	gconf_peditor_widget_set_guard (GCONF_PROPERTY_EDITOR (peditor), WID ("volume_hbox"));
 	gconf_peditor_new_numeric_range
-		(changeset, "/desktop/gnome/peripherals/keyboard/click_volume", WID ("volume_scale"), NULL);
+		(changeset, "/desktop/gnome/peripherals/keyboard/click_volume", WID ("volume_scale"),
+		 "conv-to-widget-cb",   volume_to_widget,
+		 "conv-from-widget-cb", volume_from_widget,
+		 NULL);
 	
 	g_signal_connect (G_OBJECT (WID ("bell_custom_radio")), "toggled", (GCallback) bell_guard, dialog);
 	peditor = gconf_peditor_new_select_radio
@@ -279,6 +307,8 @@ setup_dialog (GladeXML       *dialog,
 		 NULL);
 	g_signal_connect (G_OBJECT (WID ("bell_custom_radio")), "mnemonic_activate", (GCallback) mnemonic_activate, WID ("bell_custom_entry"));
 	g_signal_connect (G_OBJECT (WID ("keyboard_dialog")), "response", (GCallback) dialog_response, changeset);
+
+	g_signal_connect (G_OBJECT (WID ("accessibility_button")), "clicked", (GCallback) accessibility_button_clicked, NULL);
 }
 
 static void
@@ -300,6 +330,16 @@ get_legacy_settings (void)
 	COPY_FROM_LEGACY (int,  "/gnome/desktop/peripherals/keyboard/bell_duration", "/Desktop/Bell/duration=100");
 }
 
+#if 0
+static void
+setup_accessibility (GladeXML *dialog, GConfChangeSet *changeset)
+{
+	GtkWidget *notebook = WID ("notebook1");
+	GtkWidget *label = gtk_label_new_with_mnemonic (_("_Accessibility"));
+	GtkWidget *page = setup_accessX_dialog (changeset, FALSE);
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), page, label);
+}
+#endif
 
 int
 main (int argc, char **argv) 
@@ -329,6 +369,8 @@ main (int argc, char **argv)
 			    GNOME_PARAM_APP_DATADIR, GNOMECC_DATA_DIR,
 			    NULL);
 
+	activate_settings_daemon ();
+	
 	client = gconf_client_get_default ();
 	gconf_client_add_dir (client, "/desktop/gnome/peripherals/keyboard", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
 	gconf_client_add_dir (client, "/desktop/gnome/interface", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
@@ -339,7 +381,9 @@ main (int argc, char **argv)
 		changeset = NULL;
 		dialog = create_dialog ();
 		setup_dialog (dialog, changeset);
-
+#if 0
+		setup_accessibility (dialog, changeset);
+#endif
 		gtk_widget_show_all (WID ("keyboard_dialog"));
 		gtk_main ();
 	}
